@@ -2,7 +2,7 @@
 from .crossref_reader import get_crossref, read_crossref
 from .datacite_reader import get_datacite, read_datacite
 from .schema_org_reader import get_schema_org, read_schema_org
-from .citeproc_reader import read_citeproc
+from .csl_reader import read_csl
 from .codemeta_reader import get_codemeta, read_codemeta
 from .cff_reader import get_cff, read_cff
 from .crossref_xml_reader import get_crossref_xml, read_crossref_xml
