@@ -1,8 +1,7 @@
 """crossref_xml reader for commonmeta-py"""
 from typing import Optional
-import ast
-import traceback
 import json
+from collections import defaultdict
 import requests
 import xmltodict
 from pydash import py_
@@ -23,20 +22,17 @@ from ..base_utils import (
     parse_attributes,
     parse_xmldict,
 )
-from ..date_utils import (
-    get_date_from_parts,
-    get_date_from_crossref_parts,
-    get_datetime_from_time,
+from ..date_utils import get_date_from_crossref_parts, get_iso8601_date
+from ..doi_utils import (
+    doi_as_url,
+    get_doi_ra,
+    get_crossref_member,
+    crossref_xml_api_url,
+    normalize_doi,
 )
-from ..doi_utils import doi_as_url, get_doi_ra, crossref_xml_api_url, normalize_doi
 from ..constants import (
     Commonmeta,
-    CrossrefXml,
-    CR_TO_DC_TRANSLATIONS,
-    CR_TO_SO_TRANSLATIONS,
-    CR_TO_CP_TRANSLATIONS,
-    CR_TO_BIB_TRANSLATIONS,
-    CR_TO_RIS_TRANSLATIONS,
+    CR_TO_CM_TRANSLATIONS,
     CROSSREF_CONTAINER_TYPES,
 )
 
@@ -48,7 +44,7 @@ def get_crossref_xml(pid: str, **kwargs) -> dict:
         return {"state": "not_found"}
     url = crossref_xml_api_url(doi)
     response = requests.get(
-        url, kwargs, headers={"Accept": "text/xml;charset=utf-8"}, timeout=5
+        url, kwargs, headers={"Accept": "text/xml;charset=utf-8"}, timeout=10
     )
     if response.status_code != 200:
         return {"state": "not_found"}
@@ -65,16 +61,12 @@ def get_crossref_xml(pid: str, **kwargs) -> dict:
     data = xmltodict.parse(
         response.text, process_namespaces=True, namespaces=namespaces
     )
-    # workaround for eval, used to clean up xmltodict output
-    null = None
-    data = eval(json.dumps(data))
-    # remove namespaces from dict
-    # data = {k:v for k,v in data.items() if k != "@xmlns"}
+    data = json.loads(str(json.dumps(data)))
 
     return data
 
 
-def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
+def read_crossref_xml(data: dict, **kwargs) -> Commonmeta:
     """read_crossref_xml"""
     if data is None:
         return {"state": "not_found"}
@@ -90,14 +82,25 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
     # :sandbox, :validate, :ra))
     read_options = kwargs or {}
 
-    publisher = next(
+    member_id = next(
         (
             i
             for i in wrap(query.get("crm-item", None))
-            if i.get("@name", None) == "publisher-name"
+            if i.get("@name", None) == "member-id"
         ),
         {},
     ).get("#text", None)
+    publisher = {
+        "id": "https://api.crossref.org/members/" + member_id,
+        "name": next(
+            (
+                i
+                for i in wrap(query.get("crm-item", None))
+                if i.get("@name", None) == "publisher-name"
+            ),
+            {},
+        ).get("#text", None),
+    }
 
     # fetch metadata depending of Crossref type
     if py_.get(meta, "journal.journal_article", None):
@@ -111,8 +114,8 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
         resource_type = "Journal"
     elif py_.get(meta, "posted_content", None):
         bibmeta = meta.get("posted_content", {})
-        if publisher is None:
-            publisher = py_.get(bibmeta, "institution.institution_name", None)
+        if publisher.get("name", None) is None:
+            publisher = {"name": py_.get(bibmeta, "institution.institution_name", None)}
         resource_type = "PostedContent"
     elif py_.get(meta, "book.content_item"):
         bibmeta = py_.get(meta, "book.content_item")
@@ -128,7 +131,7 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
         resource_type = "Book"
     elif py_.get(meta, "conference", None):
         bibmeta = py_.get(meta, "conference.conference_paper", {})
-        resource_type = "ConferencePaper"
+        resource_type = "ProceedingsArticle"
     elif py_.get(meta, "sa_component", None):
         bibmeta = py_.get(meta, "sa_component.component_list.component", {})
         resource_type = "Component"
@@ -148,38 +151,20 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
         bibmeta = {}
         resource_type = ""
 
-    pid = normalize_doi(
+    id_ = normalize_doi(
         kwargs.get("doi", None)
-        or kwargs.get("pid", None)
+        or kwargs.get("id", None)
         or py_.get(bibmeta, "doi_data.doi")
     )
-    if pid:
-        doi = doi_from_url(pid)
-    else:
-        doi = None
-
+    type_ = CR_TO_CM_TRANSLATIONS.get(resource_type, "Other")
     url = parse_xmldict(
         py_.get(bibmeta, "doi_data.resource"), ignored_attributes="@content_version"
     )
     url = normalize_url(url)
-
-    schema_org = CR_TO_SO_TRANSLATIONS.get(resource_type, None) or "CreativeWork"
-    types = compact(
-        {
-            "resourceTypeGeneral": CR_TO_DC_TRANSLATIONS.get(resource_type, None)
-            or "Text",
-            "resourceType": resource_type,
-            "schemaOrg": schema_org,
-            "citeproc": CR_TO_CP_TRANSLATIONS.get(resource_type, None)
-            or "article-journal",
-            "bibtex": CR_TO_BIB_TRANSLATIONS.get(resource_type, None) or "misc",
-            "ris": CR_TO_RIS_TRANSLATIONS.get(resource_type, None) or "GEN",
-        }
-    )
-
     titles = crossref_titles(bibmeta)
 
-    date_created = next(
+    date: dict = defaultdict(list)
+    date["created"] = next(
         (
             i
             for i in wrap(query.get("crm-item", None))
@@ -187,23 +172,12 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
         ),
         {},
     ).get("#text", None)
-    date_registered = next(
-        (
-            i
-            for i in wrap(query.get("crm-item", None))
-            if i.get("@name", None) == "deposit-timestamp"
-        ),
-        {},
+    date["published"] = (
+        get_date_from_crossref_parts(bibmeta.get("publication_date", {}))
+        or get_date_from_crossref_parts(bibmeta.get("review_date", {}))
+        or date["created"]
     )
-    date_registered = get_datetime_from_time(date_registered.get("#text", None))
-    date_issued = get_date_from_crossref_parts(bibmeta.get("publication_date", {}))
-    date_reviewed = get_date_from_crossref_parts(bibmeta.get("review_date", {}))
-    date_published = date_issued or date_reviewed or date_created
-
-    # convert to date, as timestamp is fluctuating (servers in different timezones)
-    date_published = date_published[:10] if date_published else None
-
-    date_updated = next(
+    date["updated"] = next(
         (
             i
             for i in wrap(query.get("crm-item", None))
@@ -211,15 +185,11 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
         ),
         {},
     ).get("#text", None)
-    dates = [{"date": date_published, "dateType": "Issued"}]
-    if date_updated is not None:
-        dates.append({"date": date_updated, "dateType": "Updated"})
-    publication_year = int(date_published[:4]) if date_published else None
+
+    # TODO: fix timestamp. Until then, remove time as this is not always stable with Crossref (different server timezones)
+    date = {k: get_iso8601_date(v) for k, v in date.items()}
 
     descriptions = crossref_description(bibmeta)
-    program = py_.get(bibmeta, "program") or py_.get(
-        bibmeta, "crossmark.custom_metadata.program"
-    )
     funding = (
         py_.get(bibmeta, "program.assertion")
         or py_.get(bibmeta, "program.0.assertion")
@@ -228,12 +198,12 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
     )
     funding_references = crossref_funding(wrap(funding))
 
-    rights_list = (
+    license_ = (
         py_.get(bibmeta, "program.license_ref")
         or py_.get(bibmeta, "crossmark.custom_metadata.program.license_ref")
         or py_.get(bibmeta, "crossmark.custom_metadata.program.1.license_ref")
     )
-    rights = crossref_rights(wrap(rights_list))
+    license_ = crossref_license(wrap(license_))
 
     # By using book_metadata, we can account for where resource_type is `BookChapter` and not assume its a whole book
     # if book_metadata:
@@ -268,29 +238,29 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
         crossref_reference(i) for i in wrap(py_.get(bibmeta, "citation_list.citation"))
     ]
     language = py_.get(meta, "journal.journal_metadata.@language")
-    agency = bibmeta.get("@reg-agency", None) or get_doi_ra(pid)
+
+    # TODO: consistent case for DOI registration agency
+    provider = bibmeta.get("@reg-agency", None) or get_doi_ra(id_)
     state = "findable" if meta or read_options else "not_found"
 
     return {
         # required properties
-        "pid": pid,
-        "doi": doi,
+        "id": id_,
+        "type": type_,
         "url": url,
         "creators": wrap(crossref_people(bibmeta, "author")),
         "titles": presence(titles),
-        "types": types,
         "publisher": publisher,
-        "publication_year": publication_year,
+        "date": compact(date),
         # recommended and optional properties
         "subjects": presence(None),
         "contributors": crossref_people(bibmeta, "editor"),
-        "dates": dates,
         "language": language,
         "alternate_identifiers": None,
         "sizes": None,
         "formats": None,
         "version": None,
-        "rights": presence(rights),
+        "license": presence(license_),
         "descriptions": presence(descriptions),
         "geo_locations": None,
         "funding_references": presence(funding_references),
@@ -302,7 +272,7 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
         "date_updated": None,
         "content_url": presence(meta.get("contentUrl", None)),
         "container": presence(container),
-        "agency": agency.capitalize() if agency else None,
+        "provider": provider,
         "state": state,
         "schema_version": None,
     } | read_options
@@ -310,23 +280,29 @@ def read_crossref_xml(data: CrossrefXml, **kwargs) -> Commonmeta:
 
 def crossref_titles(bibmeta):
     """Title information from Crossref metadata."""
-
-    def format_element(element):
-        """Format element"""
-        if element is None or (
-            element.get("title", None) is None
-            and element.get("original_language_title", None) is None
-        ):
-            return None
-        if isinstance(element.get("title", None), str):
-            return {"title": sanitize(element.get("title", ""))}
-        if element.get("original_language_title", None):
-            return {
-                "title": sanitize(py_.get(element, "original_language_title.#text")),
-                "lang": py_.get(element, "original_language_title.language"),
+    title = parse_attributes(py_.get(bibmeta, "titles.title"))
+    subtitle = parse_attributes(py_.get(bibmeta, "titles.subtitle"))
+    original_language_title = parse_attributes(py_.get(bibmeta, "titles.original_language_title"))
+    language = parse_attributes(py_.get(bibmeta, "titles.original_language_title"), content="language")
+    if title is None and original_language_title is None:
+        return None
+    if title and original_language_title is None and subtitle is None:
+        return [{"title": sanitize(title)}]
+    if original_language_title:
+        return [compact({
+            "title": sanitize(original_language_title),
+            "lang": language,
+        })]
+    if subtitle:
+        return [compact(
+            {
+                "title": sanitize(title)
+            }),
+            {
+                "title": sanitize(subtitle),
+                "titleType": "Subtitle",
             }
-
-    return [format_element(i) for i in wrap(bibmeta.get("titles", None))]
+        ]
 
 
 def crossref_description(bibmeta):
@@ -364,7 +340,7 @@ def crossref_people(bibmeta, contributor_role="author"):
         """Format person"""
         element["givenName"] = element.get("given_name", None)
         element["familyName"] = element.get("surname", None)
-        element["nameType"] = "Personal"
+        element["type"] = "Person"
         element["affiliation"] = presence(
             [format_affiliation(i) for i in wrap(element.get("affiliation", None))]
         )
@@ -372,13 +348,7 @@ def crossref_people(bibmeta, contributor_role="author"):
             orcid = parse_xmldict(
                 element.get("ORCID"), ignored_attributes="@authenticated"
             )
-            element["nameIdentifiers"] = [
-                {
-                    "nameIdentifier": normalize_orcid(orcid),
-                    "nameIdentifierScheme": "ORCID",
-                    "schemeUri": "https://orcid.org",
-                }
-            ]
+            element["id"] = normalize_orcid(orcid)
         element = py_.omit(
             element,
             "@contributor_role",
@@ -525,9 +495,11 @@ def crossref_container(meta: dict, resource_type: str = "JournalArticle") -> dic
         ignored_attributes=["@media_type", "@xmlns"],
     )
     issn = normalize_issn(issn) if issn else None
+    isbn = py_.get(meta, f"conference.{container_type}_metadata.isbn.#text")
     container_title = (
         py_.get(meta, f"{container_type}.{container_type}_metadata.full_title")
         or py_.get(meta, f"{container_type}.{container_type}_metadata.titles.title")
+        or py_.get(meta, f"conference.{container_type}_metadata.{container_type}_title")
         or py_.get(
             meta,
             f"{container_type}.{container_type}_series_metadata.series_metadata.titles.title",
@@ -541,19 +513,23 @@ def crossref_container(meta: dict, resource_type: str = "JournalArticle") -> dic
     return compact(
         {
             "type": py_.pascal_case(container_type) if container_type else None,
-            "identifier": issn,
-            "identifierType": "ISSN" if issn else None,
+            "identifier": issn or isbn,
+            "identifierType": "ISSN" if issn else "ISBN" if isbn else None,
             "title": container_title,
             "volume": volume,
             "issue": issue,
             "firstPage": py_.get(
                 meta, f"{container_type}.{container_type}_article.pages.first_page"
             )
-            or py_.get(meta, f"{container_type}.content_item.pages.first_page"),
+            or py_.get(meta, f"{container_type}.content_item.pages.first_page")
+            or py_.get(meta, "conference.conference_paper.pages.first_page"),
             "lastPage": py_.get(
                 meta, f"{container_type}.{container_type}_article.pages.last_page"
             )
-            or py_.get(meta, f"{container_type}.content_item.pages.last_page"),
+            or py_.get(meta, f"{container_type}.content_item.pages.last_page")
+            or py_.get(meta, "conference.conference_paper.pages.last_page"),
+            "location": py_.get(meta, "conference.event_metadata.conference_location"),
+            "series": py_.get(meta, "conference.event_metadata.conference_acronym"),
         }
     )
 
@@ -589,22 +565,25 @@ def crossref_funding(funding_references: list) -> list:
                 fund_ref = funding_reference.copy()
                 fund_ref["awardNumber"] = award.get("award_number")
                 formatted_funding_references.append(fund_ref)
-        if funding_reference != {} and len(wrap(py_.get(funding_dict, "fundgroup"))) == 1:
+        if (
+            funding_reference != {}
+            and len(wrap(py_.get(funding_dict, "fundgroup"))) == 1
+        ):
             formatted_funding_references.append(funding_reference)
-             
+
     return formatted_funding_references
 
 
-def crossref_rights(rights_list: list) -> list:
-    """Get rights from Crossref"""
+def crossref_license(licenses: list) -> dict:
+    """Get license from Crossref"""
 
     def map_element(element):
         """Format element"""
-        rights_uri = parse_xmldict(
+        url = parse_xmldict(
             element, ignored_attributes=["@applies_to", "@start_date", "@end_date"]
         )
-        rights_uri = normalize_cc_url(rights_uri)
-        return dict_to_spdx({"rightsUri": rights_uri})
+        url = normalize_cc_url(url)
+        return dict_to_spdx({"url": url})
 
     # return only the first license found
-    return wrap(next((map_element(i) for i in rights_list), None))
+    return next((map_element(i) for i in licenses), None)
