@@ -2,7 +2,7 @@
 from .commonmeta_writer import write_commonmeta
 from .bibtex_writer import write_bibtex
 from .citation_writer import write_citation
-from .citeproc_writer import write_citeproc
+from .csl_writer import write_csl
 from .ris_writer import write_ris
 from .schema_org_writer import write_schema_org
 from .datacite_writer import write_datacite
