@@ -1,7 +1,7 @@
 """Bibtex writer for commonmeta-py"""
 from bibtexparser.bwriter import BibTexWriter
 from bibtexparser.bibdatabase import BibDatabase
-from bibtexparser.customization import author
+from bibtexparser.customization import page_double_hyphen
 
 from ..utils import pages_as_string
 from ..base_utils import compact
@@ -21,13 +21,14 @@ def write_bibtex(metadata: Commonmeta) -> str:
         title = metadata.titles[0].get("title", None)
     else:
         title = None
+    doi = doi_from_url(metadata.id)
 
-    id_ = metadata.id
+    id_ = doi if doi else metadata.id
     type_ = CM_TO_BIB_TRANSLATIONS.get(metadata.type, "misc")
     abstract = metadata.descriptions[0].get("description", None) if metadata.descriptions else None
     author = authors_as_string(metadata.creators)
     license_ = str(metadata.license.get("url")) if metadata.license else None
-    doi = doi_from_url(metadata.id)
+    doi = doi
     institution = metadata.publisher.get("name", None) if type_ == "phdthesis" else None
     issn = container.get("identifier", None) if container.get("identifierType", None) == "ISSN" else None
     isbn = container.get("identifier", None) if container.get("identifierType", None) == "ISBN" else None
@@ -72,6 +73,7 @@ def write_bibtex(metadata: Commonmeta) -> str:
             }
         )
     ]
+    bib_database.entries[0] = page_double_hyphen(bib_database.entries[0])
     writer = BibTexWriter()
     writer.common_strings = True
     writer.indent = "    "
